pub struct MockDriver { /* private fields */ }Expand description
The Driver trait defines the interface for connecting to different data sources and executing
SQL queries.
Implementations
Sourceimpl MockDriver
impl MockDriver
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> MockDriver
pub fn new() -> MockDriver
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockDriver
impl MockDriver
Sourcepub fn expect_identifier(&mut self) -> &mut Expectation
pub fn expect_identifier(&mut self) -> &mut Expectation
Create an Expectation for mocking the identifier method
Sourcepub fn expect_connect(&mut self) -> &mut Expectation
pub fn expect_connect(&mut self) -> &mut Expectation
Create an Expectation for mocking the connect method
Sourcepub fn expect_supports_file_type(&mut self) -> &mut Expectation
pub fn expect_supports_file_type(&mut self) -> &mut Expectation
Create an Expectation for mocking the supports_file_type method